Learn R Programming

effsize (version 0.5.4)

cohen.d: Cohen's d and Hedges g effect size

Description

Computes the Cohen's d and Hedges'g effect size statistics.

Usage

cohen.d(d, ...)

## S3 method for class 'formula': cohen.d(formula,data=list(),...)

## S3 method for class 'default': cohen.d(d,f,pooled=TRUE,paired=FALSE, na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95, ...)

Arguments

d
a numeric vector giving either the data values (if f is a factor) or the treatment group values (if f is a numeric vector)
f
either a factor with two levels or a numeric vector of values
pooled
a logical indicating whether compute pooled standard deviation or the whole sample standard deviation
paired
deprecated a logical indicating whether to consider the values as paired Since version 0.3.1 this parameter is ignored and may be removed in future code clean-ups
na.rm
logical indicating whether NA should be removed before computation
hedges.correction
logical indicating whether apply the Hedges correction
conf.level
confidence level of the confidence interval
formula
a formula of the form y ~ f, where y is a numeric variable giving the data values and f a factor with two levels giving the corresponding groups
data
an optional matrix or data frame containing the variables in the formula formula. By default the variables are taken from environment(formula).
...
further arguments to be passed to or from methods.

Value

  • A list of class effsize containing the following components:
  • estimatethe statistics estimate
  • conf.intthe confidence interval of the statistic
  • varthe estimated variance of the statistic
  • conf.levelthe confidence level used to compute the confidence interval
  • magnitudea qualitative assessment of the magnitude of effect size
  • methodthe method used for computing the effect size, either "Cohen's d" or "Hedges' g"

Details

When f in the default version is a factor or a character, it must have two values and it identifies the two groups to be compared. Otherwise (e.g. f is numeric), it is considered as a sample to be compare to d.

In the formula version, if f is expected to be a factor, if that is not the case it is coherced to a factor and a warning is issued.

The function computes the value of Cohen's d statistics (Cohen 1988). If required (hedges.correction==TRUE) the Hedges g statistics is computed instead (Hedges and Holkin, 1985).

Also a quantification of the effect size magnitude is performed using the thresholds define in Cohen (1992). The magnitude is assessed using the thresholds provided in (Cohen 1992), i.e. |d|<0.2 "negligible", |d|<0.5 "small", |d|<0.8 "medium", otherwise "large"

The variace of the d is computed using the conversion formula reportead at page 238 of Cooper et al. (2009):

$$S^2_d = \left( \frac{n_1+n_2}{n_1 n_2} + \frac{d^2}{2 df}\right) \left( \frac{n_1+n_2}{df} \right)$$

References

Cohen, J. (1988). Statistical power analysis for the behavioral sciences (2nd ed.). New York:Academic Press.

Hedges, L. V. & Olkin, I. (1985). Statistical methods for meta-analysis. Orlando, FL: Academic Press.

Cohen, J. (1992). A power primer. Psychological Bulletin, 112, 155-159.

The Handbook of Research Synthesis and Meta-Analysis (Cooper, Hedges, & Valentine, 2009)

See Also

cliff.delta, VD.A, print.effsize

Examples

Run this code
treatment = rnorm(100,mean=10)
control = rnorm(100,mean=12)
d = (c(treatment,control))
f = rep(c("Treatment","Control"),each=100)
## compute Cohen's d
## treatment and control
cohen.d(treatment,control)
## data and factor
cohen.d(d,f)
## formula interface
cohen.d(d ~ f)
## compute Hedges' g
cohen.d(d,f,hedges.correction=TRUE)

Run the code above in your browser using DataLab